% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/likelihood.R
\name{negLL.PLB.binned}
\alias{negLL.PLB.binned}
\title{Calculate negative log-likelihood for the bounded power-law
distribution given binned data}
\usage{
negLL.PLB.binned(b, w, d, J = length(d), xmin = min(w),
  xmax = max(w))
}
\arguments{
\item{b}{value of b for which to calculate the negative log-likelihood}

\item{w}{vector of length \code{J+1} giving the bin breaks \code{w_1, w_2, ..., w_{J+1}}}

\item{d}{vector of length \code{J} giving the count in each bin; must have \code{d_1, d_J > 0}}

\item{J}{number of bins (length of \code{d})}

\item{xmin}{minimum value of bins, as an input to avoid repeatedly calculating}

\item{xmax}{maximum value of bins, as an input to avoid repeatedly calculating}
}
\value{
negative log-likelihood of the parameters given the data
}
\description{
Calculates the negative log-likelihood of the parameters \code{b}, \code{xmin} and
\code{xmax} given binned data for the PLB model. Returns the negative
log-likelihood. Will be called by \code{nlm()} or similar, but \code{xmin} and \code{xmax}
will just be estimated as the minimum of lowest bin and maximum of the
largest bin, respectively, (since they are the MLEs), no need to do
numerically. Specifically this is the negative of the log-likelihood
function given in (A.70) of the MEE paper and (S.27) of the MEPS paper,
where the latter fixed a minor error in (A.75) of the MEE paper.
}
\author{
Andrew Edwards
}
